# -*- coding: utf-8 -*-
"""weatherGov is a simple wrapper that returns a usable object with current weather data from weather.gov
"""
import requests, googlemaps
import defusedxml.ElementTree as ET

class weatherGov:
    """A class for creating objects that hold weather data
    
    Example:
    from weatherGov import weatherGov 

    weather = weatherGov('ADDRESS WHERE YOU WANT TO GET WEATHER DATA', 'YOUR GOOGLE GEOCODE API KEY')
    weather.getLatLong()
    print(weather.lat)
    print(weather.long)

    weather.getCurWeather()

    print(weather.curConditions.text)
    
    """
    def __init__(self, address, clientKey):
        """Basic setup and usage:

        from weatherGov import weatherGov

        weather = weatherGov('YOUR ADDRESS', 'YOUR GOOGLE GEOCODE API KEY')

        """
        self.address = address
        self.clientKey = clientKey

    def getLatLong(self):
        """Call to get the lat and long returned as self.lat and self.long"""
        gmaps = googlemaps.Client(key=self.clientKey)
        geocode_result = gmaps.geocode(self.address)
        results = dict(geocode_result[0])
        self.lat = str(results['geometry']['location']['lat'])
        self.long = str(results['geometry']['location']['lng'])

    def getCurWeather(self):
        """Call to get the current weather conditions from the weather.gov site
        sets up self.curConditions as an XML object

        """
        weatherUrl = 'http://forecast.weather.gov/MapClick.php?lat=' + self.lat + '&lon=' + self.long + '&unit=0&lg=english&FcstType=dwml'
        res = requests.get(weatherUrl)
        try:
            res.raise_for_status()
        except Exception as exc:
            print('There was a problem: %s' % (exc))
        root = ET.fromstring(res.text)

        forecast = root.find("./data[@type='forecast']")
        timeLayout = forecast.find("./time-layout/layout-key")
        timeLayout = timeLayout.text
        searchString = "./parameters/wordedForecast[@time-layout='"+timeLayout+"']/text"
        self.curConditions = forecast.find(searchString)
